==> haskell-cipher-aes-0.2.11-19-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes
version: 0.2.11
id: cipher-aes-0.2.11-DVdARdSY56t9L6eIwC7pQC
key: cipher-aes-0.2.11-DVdARdSY56t9L6eIwC7pQC
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cipher-aes
synopsis: Fast AES cipher implementation with advanced mode of operations
description:
    Fast AES cipher implementation with advanced mode of operations.
    .
    The modes of operations available are ECB (Electronic code book),
    CBC (Cipher block chaining), CTR (Counter), XTS (XEX with ciphertext stealing),
    GCM (Galois Counter Mode).
    .
    The AES implementation uses AES-NI when available (on x86 and x86-64 architecture),
    but fallback gracefully to a software C implementation.
    .
    The software implementation uses S-Boxes, which might suffer for cache timing issues.
    However do notes that most other known software implementations, including very popular
    one (openssl, gnutls) also uses similar implementation. If it matters for your
    case, you should make sure you have AES-NI available, or you'\''ll need to use a different
    implementation.
    .
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Cipher.AES
abi: fabaef2cec7043f7e110a772c1ffa93a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cipher-aes-0.2.11
library-dirs: /usr/lib/ghc-8.2.1/site-local/cipher-aes-0.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/cipher-aes-0.2.11
hs-libraries: HScipher-aes-0.2.11-DVdARdSY56t9L6eIwC7pQC
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH
    securemem-0.1.9-Jq2KvPH2Mxu14cB2XfkmWp
    crypto-cipher-types-0.0.9-IMJAjxjit354Iejk8O3wjA
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=d344f7951d5abb0484f8cf34bb5d3e34
             securemem-0.1.9-Jq2KvPH2Mxu14cB2XfkmWp=b1ea15a2d347ff8e1d6961646ad3d429
             crypto-cipher-types-0.0.9-IMJAjxjit354Iejk8O3wjA=aec165230c99215779f44d257800686b
haddock-interfaces: /usr/share/doc/haskell-cipher-aes/html/cipher-aes.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes-0.2.11-22-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes
version: 0.2.11
id: cipher-aes-0.2.11-AxB2bnQOgKE6ffdb1IRU88
key: cipher-aes-0.2.11-AxB2bnQOgKE6ffdb1IRU88
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cipher-aes
synopsis: Fast AES cipher implementation with advanced mode of operations
description:
    Fast AES cipher implementation with advanced mode of operations.
    .
    The modes of operations available are ECB (Electronic code book),
    CBC (Cipher block chaining), CTR (Counter), XTS (XEX with ciphertext stealing),
    GCM (Galois Counter Mode).
    .
    The AES implementation uses AES-NI when available (on x86 and x86-64 architecture),
    but fallback gracefully to a software C implementation.
    .
    The software implementation uses S-Boxes, which might suffer for cache timing issues.
    However do notes that most other known software implementations, including very popular
    one (openssl, gnutls) also uses similar implementation. If it matters for your
    case, you should make sure you have AES-NI available, or you'\''ll need to use a different
    implementation.
    .
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Cipher.AES
abi: 70a53de5eb032cc88a40302c966c938c
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cipher-aes-0.2.11
library-dirs: /usr/lib/ghc-8.2.1/site-local/cipher-aes-0.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/cipher-aes-0.2.11
hs-libraries: HScipher-aes-0.2.11-AxB2bnQOgKE6ffdb1IRU88
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH
    securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE
    crypto-cipher-types-0.0.9-FlB3Fs34YAGKo4xKKfzPsc
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=d344f7951d5abb0484f8cf34bb5d3e34
             securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE=b794206c4979d66a34cacb4bf5e5db43
             crypto-cipher-types-0.0.9-FlB3Fs34YAGKo4xKKfzPsc=b9ac2fef46ec6adf6264e10e0e16963b
haddock-interfaces: /usr/share/doc/haskell-cipher-aes/html/cipher-aes.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
